@@ -25,4 +25,7 @@ class ActionsEnum:
     GET_STATUS: str = "getstatus"
     LIST_CONTRACTS: str = "listcontracts"
     GET_SOURCE_CODE: str = "getsourcecode"
-    GET_CONTRACT_CREATION: str = "getcontractcreation"
\ No newline at end of file
+    GET_CONTRACT_CREATION: str = "getcontractcreation"
+    GET_BLOCK_REWARD: str = "getblockreward"
+    GET_BLOCK_COUNTDOWN: str = "getblockcountdown"
+    GET_ABI: str = "getabi"
\ No newline at end of file
